<?php
// الاتصال بقاعدة البيانات
$host = "localhost";
$user = "root";
$pass = "";
$db = "maids_booking";

include "config.php";
if ($conn->connect_error) {
  die("فشل الاتصال بقاعدة البيانات: " . $conn->connect_error);
}

// الحصول على رقم الحجز من الرابط
$booking_id = $_GET['booking_id'] ?? '';

$sql = "SELECT * FROM monthly_bookings WHERE id = ?";
$stmt = $conn->prepare($sql);
$stmt->bind_param("i", $booking_id);
$stmt->execute();
$result = $stmt->get_result();

if ($result->num_rows === 0) {
  die("لم يتم العثور على الحجز.");
}

$row = $result->fetch_assoc();
$stmt->close();
$conn->close();
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
  <meta charset="UTF-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
  <title>تأكيد الحجز والدفع</title>
  <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.rtl.min.css" rel="stylesheet">
  <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
  <style>
    body {
      font-family: 'Cairo', sans-serif;
      background-color: #f2f2f2;
    }
    .container {
      max-width: 600px;
      margin: 30px auto;
      background: #fff;
      padding: 2rem;
      border-radius: 12px;
      box-shadow: 0 0 12px rgba(0,0,0,0.1);
    }
    .summary-box {
      background-color: #f8f9fa;
      border: 1px solid #ddd;
      padding: 1rem;
      border-radius: 10px;
      margin-bottom: 1.5rem;
    }
    .summary-box p {
      font-size: 1.05rem;
      margin: 0.5rem 0;
    }
    .paid { color: green; font-weight: bold; }
    .remaining { color: #dc3545; font-weight: bold; }
    .alert {
      font-size: 0.95rem;
      background-color: #e2f0d9;
      border-color: #c6e0b4;
      color: #2e7d32;
      border-radius: 6px;
      padding: 1rem;
    }
    .btn-payment {
      width: 100%;
      font-size: 18px;
      padding: 12px;
    }
    .btn-secondary {
      margin-top: 10px;
    }
    #countdown {
      font-size: 1.2rem;
      font-weight: bold;
      color: #ff5722;
      margin-bottom: 1rem;
      text-align: center;
    }
  </style>
</head>
<body>

<div class="container">
  <h3 class="text-center text-success mb-3">تأكيد الحجز والدفع</h3>
  <p class="text-center text-muted">✅ يرجى التأكد من التفاصيل التالية. عند الضغط على زر الدفع، سيتم حجز الخدمة مباشرة.</p>

  <div class="summary-box">
    <p>🔢 <strong>رقم الحجز:</strong> <?php echo htmlspecialchars($row['id']); ?></p>
    <p>📅 <strong>تاريخ الحجز:</strong> <?php echo htmlspecialchars($row['created_at']); ?></p>
    <p>👤 <strong>اسم العميل:</strong> <?php echo htmlspecialchars($row['full_name']); ?></p>
    <p>💰 <strong>إجمالي الحجز:</strong> 10 د.ك</p>
    <p>✅ <strong class="paid">المبلغ المدفوع الآن:</strong> 2 د.ك</p>
    <p>⏳ <strong class="remaining">المتبقي:</strong> 8 د.ك</p>
  </div>

  <div id="countdown">⏱️ ينتهي الحجز خلال: 15:00</div>

  <div class="alert text-center">
    💬 عند الضغط على الدفع، سيتم حجز الخدمة مباشرة. يمكنك تعديل البيانات قبل الدفع.
  </div>

  
  <form method="POST" action="payment-process.php">
    <input type="hidden" name="booking_id" value="<?php echo htmlspecialchars($row['id']); ?>">
    <input type="hidden" name="amount" value="2">
    <button type="submit" class="btn btn-success btn-payment">🔒 ادفع الآن 2 د.ك عبر KNET</button>
  </form>

  <button class="btn btn-secondary w-100" onclick="window.location.href='booking-monthly.php'">🔄 تعديل البيانات</button>
</div>

<script>
  let timeLeft = 15 * 60;
  const countdownEl = document.getElementById('countdown');

  const timer = setInterval(() => {
    let minutes = Math.floor(timeLeft / 60);
    let seconds = timeLeft % 60;
    countdownEl.textContent = '⏱️ ينتهي الحجز خلال: ' + minutes + ':' + String(seconds).padStart(2, '0');
    timeLeft--;
    if (timeLeft < 0) {
      clearInterval(timer);
      countdownEl.textContent = '⛔ انتهت صلاحية الحجز.';
      document.querySelector('.btn-payment').disabled = true;
    }
  }, 1000);
</script>

</body>
</html>